@@ -256,6 +256,7 @@ class DeleteFlavor(FlavorCommand):
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)', parsed_args)
         client = self.app.client_manager.warre
+
         try:
             client.flavors.delete(parsed_args.id)
         except exceptions.NotFound as ex:
@@ -345,9 +346,49 @@ class ListAccess(command.Lister):
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)', parsed_args)
         client = self.app.client_manager.warre
-        flavorprojects = client.flavorprojects.list()
+
+        flavorprojects = client.flavorprojects.list(
+            flavor_id=parsed_args.flavor_id, project_id=parsed_args.project_id)
         columns = ['id', 'flavor', 'project_id']
         return (
             columns,
             (osc_utils.get_item_properties(q, columns) for q in flavorprojects)
         )
+
+
+class FlavorSlots(command.Lister):
+    """Show flavor free slots."""
+
+    log = logging.getLogger(__name__ + '.FlavorSlots')
+
+    def take_action(self, parsed_args):
+        self.log.debug('take_action(%s)', parsed_args)
+        client = self.app.client_manager.warre
+        slots = client.flavors.free_slots(parsed_args.id, parsed_args.start,
+            parsed_args.end)
+        columns = ['start', 'end']
+        return (
+            columns,
+            (osc_utils.get_dict_properties(q, columns) for q in slots)
+        )
+
+    def get_parser(self, prog_name):
+        parser = super(command.Lister, self).get_parser(prog_name)
+        parser.add_argument(
+            'id',
+            metavar='<id>',
+            help=('ID of flavor')
+        )
+        parser.add_argument(
+            '--start',
+            metavar='<start>',
+            default=None,
+            help='Date (YYYY-MM-DD)',
+        )
+        parser.add_argument(
+            '--end',
+            metavar='<end>',
+            default=None,
+            help='Date (YYYY-MM-DD)',
+        )
+        return parser
